@@ -228,7 +228,7 @@ class SSHClient(object):
             else:
                 channel = self.__ssh.get_transport().open_session()
                 channel.get_pty(width=80, height=100)  # 获取虚拟终端
-                stdin, stdout, stderr = channel.exec_command(cmd,timeout=timeout)
+                stdin, stdout, stderr = channel.exec_command(cmd)
                 exit_status = stdout.channel.recv_exit_status()
                 std_output = stdout.read().decode()
                 std_err = stderr.read().decode()
